@@ -16,7 +16,7 @@
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 import numpy as np
-from typing import Union
+from typing import Union, Tuple, List
 from GridCalEngine.basic_structures import Logger
 from GridCalEngine.Devices.Substation.bus import Bus
 from GridCalEngine.Devices.Substation.connectivity_node import ConnectivityNode
@@ -104,7 +104,7 @@ class Line(BranchParent):
                               device_type=DeviceType.LineDevice)
 
         # line length in km
-        self.length = length
+        self._length = length
 
         # line impedance tolerance
         self.tolerance = tolerance
@@ -140,7 +140,7 @@ class Line(BranchParent):
 
         # association with various templates
         self.possible_tower_types: Associations = Associations(device_type=DeviceType.OverheadLineTypeDevice)
-        self.possible_undergroud_line_types: Associations = Associations(device_type=DeviceType.UnderGroundLineDevice)
+        self.possible_underground_line_types: Associations = Associations(device_type=DeviceType.UnderGroundLineDevice)
         self.possible_sequence_line_types: Associations = Associations(device_type=DeviceType.SequenceLineDevice)
 
         # Line locations
@@ -183,7 +183,7 @@ class Line(BranchParent):
                       definition='Possible overhead line types (>1 to denote association), - to denote no association',
                       display=False)
 
-        self.register(key='possible_undergroud_line_types', units='', tpe=SubObjectType.Associations,
+        self.register(key='possible_underground_line_types', units='', tpe=SubObjectType.Associations,
                       definition='Possible underground line types (>1 to denote association), - to denote no association',
                       display=False)
 
@@ -191,6 +191,25 @@ class Line(BranchParent):
                       definition='Possible sequence line types (>1 to denote association), - to denote no association',
                       display=False)
 
+    @property
+    def length(self) -> float:
+        """
+        Line length in km
+        :return: float
+        """
+        return self._length
+
+    @length.setter
+    def length(self, val: float):
+        if isinstance(val, float):
+            if val > 0.0:
+                self._length = val
+            else:
+                print('The length cannot be zero, setting it to 1.0 km')
+                self._length = 1.0
+        else:
+            raise Exception('The length must be a float value')
+
     @property
     def temp_oper_prof(self) -> Profile:
         """
@@ -278,7 +297,24 @@ class Line(BranchParent):
         else:
             logger.add_error('Template not recognised', self.name)
 
-    def get_save_data(self):
+    def get_line_type(self) -> SequenceLineType:
+        """
+        Get the equivalent sequence line type of this line
+        :return: SequenceLineType
+        """
+        if self.length == 0.0:
+            raise Exception("Length must be greater than 0")
+
+        return SequenceLineType(name=f"{self.name}_type",
+                                Imax=1, Vnom=self.get_max_bus_nominal_voltage(),
+                                R=self.R / self.length,
+                                X=self.X / self.length,
+                                B=self.B / self.length,
+                                R0=self.R0 / self.length,
+                                X0=self.X0 / self.length,
+                                B0=self.B0 / self.length)
+
+    def get_save_data(self) -> List[str]:
         """
         Return the data that matches the edit_headers
         :return:
@@ -302,11 +338,11 @@ class Line(BranchParent):
                 data.append(obj)
         return data
 
-    def fix_inconsistencies(self, logger: Logger):
+    def fix_inconsistencies(self, logger: Logger) -> bool:
         """
         Fix the inconsistencies
         :param logger:
-        :return:
+        :return: any error
         """
         errors = False
 
@@ -319,9 +355,9 @@ class Line(BranchParent):
 
     def should_this_be_a_transformer(self, branch_connection_voltage_tolerance: float = 0.1) -> bool:
         """
-
+        Check if ths should be a transformer
         :param branch_connection_voltage_tolerance:
-        :return:
+        :return: should it be a transformer?
         """
         if self.bus_to is not None and self.bus_from is not None:
             V1 = min(self.bus_to.Vnom, self.bus_from.Vnom)
@@ -385,47 +421,69 @@ class Line(BranchParent):
         self.rate = np.round(Imax * Vf * 1.73205080757, 6)  # nominal power in MVA = kA * kV * sqrt(3)
         self.length = length
 
-    def set_data_from(self, second_Line: "Line"):
+    def get_virtual_taps(self) -> Tuple[float, float]:
         """
-        Set the data from another line
-        :param second_Line:
-        :return:
+        Get the branch virtual taps
+
+        The virtual taps generate when a line nominal voltage ate the two connection buses differ
+
+        Returns:
+            **tap_f** (float, 1.0): Virtual tap at the *from* side
+            **tap_t** (float, 1.0): Virtual tap at the *to* side
         """
-        self.copy()
-        self.bus_from = second_Line.bus_from
-        self.bus_to = second_Line.bus_to
-        self.cn_from = second_Line.cn_from
-        self.cn_to = second_Line.cn_to
-        self.name = second_Line.name
-        self.idtag = second_Line.idtag
-        self.code = second_Line.code
-        self.R = second_Line.R
-        self.X = second_Line.X
-        self.B = second_Line.B
-        self.rate = second_Line.rate
-        self.active = second_Line.active
-        self.tolerance = second_Line.tolerance
-        self.Cost = second_Line.Cost
-        self.mttf = second_Line.mttf
-        self.mttr = second_Line.mttr
-        self.r_fault = second_Line.r_fault
-        self.x_fault = second_Line.x_fault
-        self.fault_pos = second_Line.fault_pos
-        self.length = second_Line.length
-        self.temp_base = second_Line.temp_base
-        self.temp_oper = second_Line.temp_oper
-        self.alpha = second_Line.alpha
-        self.template = second_Line.template
-        self.contingency_factor = second_Line.contingency_factor
-        self.protection_rating_factor = second_Line.protection_rating_factor
-        self.contingency_enabled = second_Line.contingency_enabled
-        self.monitor_loading = second_Line.monitor_loading
-        self.R0 = second_Line.R0
-        self.X0 = second_Line.X0
-        self.B0 = second_Line.B0
-        self.R2 = second_Line.R2
-        self.X2 = second_Line.X2
-        self.B2 = second_Line.B2
-        self.capex = second_Line.capex
-        self.opex = second_Line.opex
-        self.build_status = second_Line.build_status
+        # resolve how the transformer is actually connected and set the virtual taps
+        bus_f_v = self.bus_from.Vnom
+        bus_t_v = self.bus_to.Vnom
+
+        if bus_f_v == bus_t_v:
+            return 1.0, 1.0
+        else:
+            if bus_f_v > 0.0 and bus_t_v > 0.0:
+                return 1.0, bus_f_v / bus_t_v
+            else:
+                return 1.0, 1.0
+
+    # def set_data_from(self, second_Line: "Line"):
+    #     """
+    #     Set the data from another line
+    #     :param second_Line:
+    #     :return:
+    #     """
+    #     self.copy()
+    #     self.bus_from = second_Line.bus_from
+    #     self.bus_to = second_Line.bus_to
+    #     self.cn_from = second_Line.cn_from
+    #     self.cn_to = second_Line.cn_to
+    #     self.name = second_Line.name
+    #     self.idtag = second_Line.idtag
+    #     self.code = second_Line.code
+    #     self.R = second_Line.R
+    #     self.X = second_Line.X
+    #     self.B = second_Line.B
+    #     self.rate = second_Line.rate
+    #     self.active = second_Line.active
+    #     self.tolerance = second_Line.tolerance
+    #     self.Cost = second_Line.Cost
+    #     self.mttf = second_Line.mttf
+    #     self.mttr = second_Line.mttr
+    #     self.r_fault = second_Line.r_fault
+    #     self.x_fault = second_Line.x_fault
+    #     self.fault_pos = second_Line.fault_pos
+    #     self.length = second_Line.length
+    #     self.temp_base = second_Line.temp_base
+    #     self.temp_oper = second_Line.temp_oper
+    #     self.alpha = second_Line.alpha
+    #     self.template = second_Line.template
+    #     self.contingency_factor = second_Line.contingency_factor
+    #     self.protection_rating_factor = second_Line.protection_rating_factor
+    #     self.contingency_enabled = second_Line.contingency_enabled
+    #     self.monitor_loading = second_Line.monitor_loading
+    #     self.R0 = second_Line.R0
+    #     self.X0 = second_Line.X0
+    #     self.B0 = second_Line.B0
+    #     self.R2 = second_Line.R2
+    #     self.X2 = second_Line.X2
+    #     self.B2 = second_Line.B2
+    #     self.capex = second_Line.capex
+    #     self.opex = second_Line.opex
+    #     self.build_status = second_Line.build_status
