@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 from GridCalEngine.IO.base.units import UnitMultiplier, UnitSymbol
-from GridCalEngine.IO.cim.cgmes.cgmes_v2_4_15.devices.conducting_equipment import ConductingEquipment
+from GridCalEngine.IO.cim.cgmes.cgmes_v3_0_0.devices.conducting_equipment import ConductingEquipment
 from GridCalEngine.IO.cim.cgmes.cgmes_enums import cgmesProfile, UnitSymbol
 
 
@@ -30,6 +30,6 @@ class Conductor(ConductingEquipment):
 			class_type=float,
 			multiplier=UnitMultiplier.k,
 			unit=UnitSymbol.m,
-			description='''Unit of length. Never negative.''',
+			description='''Unit of length. It shall be a positive value or zero.''',
 			profiles=[]
 		)
