@@ -1,5 +1,5 @@
 # GridCal
-# Copyright (C) 2015 - 2023 Santiago Peñate Vera
+# Copyright (C) 2015 - 2024 Santiago Peñate Vera
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -358,7 +358,21 @@ class RawVscDCLine(RawObject):
 
         var = [self.O1, self.F1, self.O2, self.F2, self.O3, self.F3, self.O4, self.F4]
 
-        if version >= 35:
+        if 34 <= version >= 35:
+            '''
+            NAME, MDC, RDC, O1, F1, ... O4, F4
+            IBUS,TYPE,MODE,DCSET,ACSET,ALOSS,BLOSS,MINLOSS,SMAX,IMAX,PWF,MAXQ,MINQ,REMOT,RMPCT
+            '''
+
+            self.NAME, self.MDC, self.RDC, *var = data[0]
+
+            (self.IBUS1, self.TYPE1, self.MODE1, self.DCSET1, self.ACSET1, self.ALOSS1, self.BLOSS1, self.MINLOSS1,
+             self.SMAX1, self.IMAX1, self.PWF1, self.MAXQ1, self.MINQ1, self.VSREG1, self.NREG1, self.RMPCT1) = data[1]
+
+            (self.IBUS2, self.TYPE2, self.MODE2, self.DCSET2, self.ACSET2, self.ALOSS2, self.BLOSS2, self.MINLOSS2,
+             self.SMAX2, self.IMAX2, self.PWF2, self.MAXQ2, self.MINQ2, self.VSREG2, self.NREG2, self.RMPCT2) = data[2]
+
+        if 30 <= version <= 33:
 
             '''
             NAME, MDC, RDC, O1, F1, ... O4, F4
@@ -367,26 +381,11 @@ class RawVscDCLine(RawObject):
 
             self.NAME, self.MDC, self.RDC, *var = data[0]
 
-            self.IBUS1, self.TYPE1, self.MODE1, self.DCSET1, self.ACSET1, self.ALOSS1, self.BLOSS1, self.MINLOSS1, \
-            self.SMAX1, self.IMAX1, self.PWF1, self.MAXQ1, self.MINQ1, self.VSREG1, self.NREG1, self.RMPCT1 = data[1]
+            (self.IBUS1, self.TYPE1, self.MODE1, self.DCSET1, self.ACSET1, self.ALOSS1, self.BLOSS1, self.MINLOSS1,
+                self.SMAX1, self.IMAX1, self.PWF1, self.MAXQ1, self.MINQ1, self.REMOT1, self.RMPCT1) = data[1]
 
-            self.IBUS2, self.TYPE2, self.MODE2, self.DCSET2, self.ACSET2, self.ALOSS2, self.BLOSS2, self.MINLOSS2, \
-            self.SMAX2, self.IMAX2, self.PWF2, self.MAXQ2, self.MINQ2, self.VSREG2, self.NREG2, self.RMPCT2 = data[2]
-
-        if 30 <= version <= 34:
-
-            '''
-            NAME, MDC, RDC, O1, F1, ... O4, F4
-            IBUS,TYPE,MODE,DCSET,ACSET,ALOSS,BLOSS,MINLOSS,SMAX,IMAX,PWF,MAXQ,MINQ,REMOT,RMPCT
-            '''
-
-            self.NAME, self.MDC, self.RDC, *var = data[0]
-
-            self.IBUS1, self.TYPE1, self.MODE1, self.DCSET1, self.ACSET1, self.ALOSS1, self.BLOSS1, self.MINLOSS1, \
-            self.SMAX1, self.IMAX1, self.PWF1, self.MAXQ1, self.MINQ1, self.REMOT1, self.RMPCT1 = data[1]
-
-            self.IBUS2, self.TYPE2, self.MODE2, self.DCSET2, self.ACSET2, self.ALOSS2, self.BLOSS2, self.MINLOSS2, \
-            self.SMAX2, self.IMAX2, self.PWF2, self.MAXQ2, self.MINQ2, self.REMOT2, self.RMPCT2 = data[2]
+            (self.IBUS2, self.TYPE2, self.MODE2, self.DCSET2, self.ACSET2, self.ALOSS2, self.BLOSS2, self.MINLOSS2,
+                self.SMAX2, self.IMAX2, self.PWF2, self.MAXQ2, self.MINQ2, self.REMOT2, self.RMPCT2) = data[2]
 
         elif version == 29:
 
@@ -399,10 +398,10 @@ class RawVscDCLine(RawObject):
             self.NAME, self.MDC, self.RDC, *var = data[0]
 
             self.IBUS1, self.TYPE1, self.MODE1, self.DCSET1, self.ACSET1, self.ALOSS1, self.BLOSS1, self.MINLOSS1, \
-            self.SMAX1, self.IMAX1, self.PWF1, self.MAXQ1, self.MINQ1, self.REMOT1, self.RMPCT1 = data[1]
+                self.SMAX1, self.IMAX1, self.PWF1, self.MAXQ1, self.MINQ1, self.REMOT1, self.RMPCT1 = data[1]
 
             self.IBUS2, self.TYPE2, self.MODE2, self.DCSET2, self.ACSET2, self.ALOSS2, self.BLOSS2, self.MINLOSS2, \
-            self.SMAX2, self.IMAX2, self.PWF2, self.MAXQ2, self.MINQ2, self.REMOT2, self.RMPCT2 = data[2]
+                self.SMAX2, self.IMAX2, self.PWF2, self.MAXQ2, self.MINQ2, self.REMOT2, self.RMPCT2 = data[2]
 
         else:
             logger.add_warning('Version not implemented for VSC-DC Lines', str(version))
@@ -420,12 +419,12 @@ class RawVscDCLine(RawObject):
             l0 = self.format_raw_line([self.NAME, self.MDC, self.RDC] + var)
 
             l1 = self.format_raw_line([self.IBUS1, self.TYPE1, self.MODE1, self.DCSET1, self.ACSET1, self.ALOSS1,
-                                      self.BLOSS1, self.MINLOSS1, self.SMAX1, self.IMAX1, self.PWF1,
-                                      self.MAXQ1, self.MINQ1, self.VSREG1, self.NREG1, self.RMPCT1])
+                                       self.BLOSS1, self.MINLOSS1, self.SMAX1, self.IMAX1, self.PWF1,
+                                       self.MAXQ1, self.MINQ1, self.VSREG1, self.NREG1, self.RMPCT1])
 
             l2 = self.format_raw_line([self.IBUS2, self.TYPE2, self.MODE2, self.DCSET2, self.ACSET2, self.ALOSS2,
-                                      self.BLOSS2, self.MINLOSS2, self.SMAX2, self.IMAX2, self.PWF2, self.MAXQ2,
-                                      self.MINQ2, self.VSREG2, self.NREG2, self.RMPCT2])
+                                       self.BLOSS2, self.MINLOSS2, self.SMAX2, self.IMAX2, self.PWF2, self.MAXQ2,
+                                       self.MINQ2, self.VSREG2, self.NREG2, self.RMPCT2])
 
             return l0 + '\n' + l1 + '\n' + l2
 
@@ -477,5 +476,3 @@ class RawVscDCLine(RawObject):
         :return:
         """
         return "{0}_{1}_1".format(self.IBUS1, self.IBUS2)
-
-
