@@ -215,6 +215,7 @@ class InvestmentsEvaluationDriver(TimeSeriesDriverTemplate):
         :param opf_time_series_results: Optimal power flow results
         :param clustering_results: Clustering results
         """
+
         TimeSeriesDriverTemplate.__init__(self,
                                           grid=grid,
                                           time_indices=time_indices,
@@ -242,7 +243,7 @@ class InvestmentsEvaluationDriver(TimeSeriesDriverTemplate):
         self.max_iter = options.max_eval
 
         # gather a dictionary of all the elements, this serves for the investments generation
-        self.get_all_elements_dict = self.grid.get_all_elements_dict()
+        self.get_all_elements_dict, dict_ok = self.grid.get_all_elements_dict()
 
         # compose useful arrays
         self.vm_cost = np.array([e.Vm_cost for e in grid.get_buses()], dtype=float)
@@ -624,6 +625,7 @@ class InvestmentsEvaluationDriver(TimeSeriesDriverTemplate):
 
         # optimize
         X, obj_values = NSGA_2(
+            grid=self.grid,
             obj_func=self.objective_function,
             n_obj=len(ret),
             max_evals=self.options.max_eval,  # termination
@@ -633,7 +635,16 @@ class InvestmentsEvaluationDriver(TimeSeriesDriverTemplate):
             # eta=30,
         )
 
-        self.results.set_best_combination(combination=X[:, 0])
+        res_x = []
+        for i, v in enumerate(X):
+            if isinstance(v, dict):
+                vall = list(v.values())[0]
+                res_x.append(vall)
+            else:
+                res_x.append(v)
+
+        self.results.set_best_combination(combination=np.array(res_x))
+        # self.results.set_best_combination(combination=X[:, 0])
 
         self.results.trim()
 
@@ -664,6 +675,9 @@ class InvestmentsEvaluationDriver(TimeSeriesDriverTemplate):
         elif self.options.solver == InvestmentEvaluationMethod.MixedVariableGA:
             self.optimized_evaluation_mixed_nsga2()
 
+        elif self.options.solver == InvestmentEvaluationMethod.FromPlugin:
+            self.options.plugin_fcn_ptr(self)
+
         else:
             raise Exception('Unsupported method')
 
@@ -673,6 +687,7 @@ class InvestmentsEvaluationDriver(TimeSeriesDriverTemplate):
             self.logger.add_info(msg=f"Best combination", device=inv.idtag, value=inv.name)
 
         # this stores the pareto indices in the solution object for later usage
-        self.results.get_pareto_indices()
+        if self.results.current_evaluation > 0:
+            self.results.get_pareto_indices()
 
         self.toc()
