@@ -1,5 +1,5 @@
 # GridCal
-# Copyright (C) 2015 - 2023 Santiago Peñate Vera
+# Copyright (C) 2015 - 2024 Santiago Peñate Vera
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -20,8 +20,8 @@ import numpy as np
 from typing import Dict, Union
 
 from GridCalEngine.Simulations.results_template import ResultsTemplate
-from GridCalEngine.Simulations.result_types import ResultTypes
-from GridCalEngine.Simulations.results_table import ResultsTable
+from GridCalEngine.enumerations import ResultTypes, StudyResultsType
+from GridCalEngine.Simulations.results_table import ResultsTable, DeviceType
 
 
 class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
@@ -30,10 +30,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
             self,
             bus_names: np.ndarray,
             branch_names: np.ndarray,
-            generator_names: np.ndarray,
-            load_names: np.ndarray,
-            rates: np.ndarray,
-            contingency_rates: np.ndarray,
+            hvdc_names: np.ndarray,
             time_array: np.ndarray,
             time_indices: np.ndarray,
             sampled_probabilities: Union[np.ndarray, None] = None,
@@ -46,10 +43,6 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
         :param bus_names:
         :param branch_names:
-        :param generator_names:
-        :param load_names:
-        :param rates:
-        :param contingency_rates:
         :param time_array:
         :param time_indices:
         :param sampled_probabilities:
@@ -80,19 +73,42 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
                     ResultTypes.TsContingencyBranches,
                 ],
             },
-            data_variables=[],
             time_array=time_array,
-            clustering_results=None)
+            clustering_results=None,
+            study_results_type=StudyResultsType.NetTransferCapacityTimeSeries)
+
+        nt = len(time_indices)
+        m = len(branch_names)
+        n = len(bus_names)
+        nhvdc = len(hvdc_names)
 
         # self.time_array = time_array
         self.time_indices = time_indices
         self.branch_names = np.array(branch_names, dtype=object)
         self.bus_names = bus_names
-        self.generator_names = generator_names
-        self.load_names = load_names
 
-        self.rates = rates
-        self.contingency_rates = contingency_rates
+        self.voltage = np.zeros((nt, n), dtype=complex)
+        self.Sbus = np.zeros((nt, n), dtype=complex)
+        self.bus_shadow_prices = np.zeros((nt, n), dtype=float)
+
+        self.Sf = np.zeros((nt, m), dtype=complex)
+        self.St = np.zeros((nt, m), dtype=complex)
+        self.loading = np.zeros((nt, m), dtype=float)
+        self.losses = np.zeros((nt, m), dtype=float)
+        self.phase_shift = np.zeros((nt, m), dtype=float)
+        self.overloads = np.zeros((nt, m), dtype=float)
+        self.rates = np.zeros(m)
+        self.contingency_rates = np.zeros(m)
+        self.contingency_flows_list = list()
+        self.contingency_indices_list = list()  # [(t, m, c), ...]
+        self.contingency_flows_slacks_list = list()
+
+        self.hvdc_Pf = np.zeros((nt, nhvdc), dtype=float)
+        self.hvdc_loading = np.zeros((nt, nhvdc), dtype=float)
+
+        self.monitor = np.zeros((nt, m), dtype=bool)
+        self.monitor_type = np.zeros((nt, m), dtype=object)
+
         self.base_exchange = 0
         self.raw_report = None
         self.report = None
@@ -124,7 +140,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def get_alpha_report(self):
 
-        title = ResultTypes.TsAlphaReport.value[0]
+        title = ResultTypes.TsAlphaReport.value
 
         if title not in self.reports.keys():
             self.create_alpha_report()
@@ -133,7 +149,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def get_alphan1_report(self):
 
-        title = ResultTypes.TsWorstAlphaN1Report.value[0]
+        title = ResultTypes.TsWorstAlphaN1Report.value
 
         if title not in self.reports.keys():
             self.create_worst_alpha_n1_report()
@@ -142,7 +158,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def get_generation_power_report(self):
 
-        title = ResultTypes.TsGenerationPowerReport.value[0]
+        title = ResultTypes.TsGenerationPowerReport.value
 
         if title not in self.reports.keys():
             self.create_generation_power_report()
@@ -151,7 +167,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def get_generation_delta_report(self):
 
-        title = ResultTypes.TsGenerationDeltaReport.value[0]
+        title = ResultTypes.TsGenerationDeltaReport.value
 
         if title not in self.reports.keys():
             self.create_generation_delta_report()
@@ -160,7 +176,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def get_base_report(self, loading_threshold=0.0, reverse=True):
 
-        title = f'{ResultTypes.TsBaseFlowReport.value[0]}. ' \
+        title = f'{ResultTypes.TsBaseFlowReport.value}. ' \
                 f'Loading threshold: {str(loading_threshold)}. ' \
                 f'Reverse: {str(reverse)}'
 
@@ -174,7 +190,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def get_contingency_full_report(self, loading_threshold, reverse=True):
 
-        title = f'{ResultTypes.TsContingencyFlowReport.value[0]}. ' \
+        title = f'{ResultTypes.TsContingencyFlowReport.value}. ' \
                 f'Loading threshold: {str(loading_threshold)}. ' \
                 f'Reverse: {str(reverse)}'
 
@@ -187,7 +203,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def get_branch_monitoring_report(self):
 
-        title = ResultTypes.TsBranchMonitoring.value[0]
+        title = ResultTypes.TsBranchMonitoring.value
 
         if title not in self.reports.keys():
             self.create_branch_monitoring_report()
@@ -196,7 +212,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def get_critical_branches_report(self, loading_threshold=100, reverse=True):
 
-        title = f'{ResultTypes.TsCriticalBranches.value[0]}. ' \
+        title = f'{ResultTypes.TsCriticalBranches.value}. ' \
                 f'Loading threshold: {str(loading_threshold)}. ' \
                 f'Reverse: {str(reverse)}'
 
@@ -210,7 +226,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def get_contingency_branches_report(self, loading_threshold=100, reverse=True):
 
-        title = f'{ResultTypes.TsContingencyBranches.value[0]}. ' \
+        title = f'{ResultTypes.TsContingencyBranches.value}. ' \
                 f'Loading threshold: {str(loading_threshold)}. ' \
                 f'Reverse: {str(reverse)}'
 
@@ -228,45 +244,45 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
         tm1 = time.time()
         self.create_generation_power_report()
-        print(f'Generation power report created in {time.time()-tm1:.2f} scs.')
+        print(f'Generation power report created in {time.time() - tm1:.2f} scs.')
 
         tm1 = time.time()
         self.create_generation_delta_report()
-        print(f'Generation delta report created in {time.time()-tm1:.2f} scs.')
+        print(f'Generation delta report created in {time.time() - tm1:.2f} scs.')
 
         tm1 = time.time()
         self.create_alpha_report()
-        print(f'Alpha report created in {time.time()-tm1:.2f} scs.')
+        print(f'Alpha report created in {time.time() - tm1:.2f} scs.')
 
         tm1 = time.time()
         self.create_worst_alpha_n1_report()
-        print(f'Worst alpha n1 report created in {time.time()-tm1:.2f} scs.')
+        print(f'Worst alpha n1 report created in {time.time() - tm1:.2f} scs.')
 
         tm1 = time.time()
         self.create_branch_monitoring_report()
-        print(f'Branch monitoring report created in {time.time()-tm1:.2f} scs.')
+        print(f'Branch monitoring report created in {time.time() - tm1:.2f} scs.')
 
         tm1 = time.time()
         self.create_base_report(
             loading_threshold=loading_threshold,
             reverse=reverse
         )
-        print(f'Base report created in {time.time()-tm1:.2f} scs.')
+        print(f'Base report created in {time.time() - tm1:.2f} scs.')
 
         tm1 = time.time()
         self.create_contingency_full_report(
             loading_threshold=loading_threshold,
             reverse=reverse
         )
-        print(f'Contingency power report created in {time.time()-tm1:.2f} scs.')
+        print(f'Contingency power report created in {time.time() - tm1:.2f} scs.')
 
         tm1 = time.time()
         self.create_critical_branches_report(
             loading_threshold=100,
             reverse=reverse
         )
-        print(f'Critical branches report created in {time.time()-tm1:.2f} scs.')
-        print(f'All final reports created in {time.time()-tm0:.2f} scs.')
+        print(f'Critical branches report created in {time.time() - tm1:.2f} scs.')
+        print(f'All final reports created in {time.time() - tm0:.2f} scs.')
 
     def mdl(self, result_type) -> "ResultsTable":
         """
@@ -312,7 +328,6 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
         else:
             raise Exception('No results available')
 
-
     def get_steps(self):
         return
 
@@ -374,7 +389,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
         # get columns indices to sort
         ttc_idx = list(map(str.lower, columns)).index('ttc')
-        load_col_name = [c for c in columns if any(x in c.lower().split(' ') for x in ['flow', 'load' ]) and '%' in c][0]
+        load_col_name = [c for c in columns if any(x in c.lower().split(' ') for x in ['flow', 'load']) and '%' in c][0]
         cload_idx = columns.index(load_col_name)
         time_idx = list(map(str.lower, columns)).index('time')
 
@@ -407,7 +422,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def create_alpha_report(self):
 
-        title = ResultTypes.TsAlphaReport.value[0]
+        title = ResultTypes.TsAlphaReport.value
 
         result = list(self.results_dict.values())[0]
         columns = ['Time index', 'Time'] + list(result.branch_names)
@@ -429,7 +444,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def create_worst_alpha_n1_report(self):
 
-        title = ResultTypes.TsWorstAlphaN1Report.value[0]
+        title = ResultTypes.TsWorstAlphaN1Report.value
 
         result = list(self.results_dict.values())[0]
         columns = ['Time index', 'Time'] + list(result.branch_names)
@@ -451,7 +466,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def create_generation_power_report(self):
 
-        title = ResultTypes.TsGenerationPowerReport.value[0]
+        title = ResultTypes.TsGenerationPowerReport.value
 
         labels = self.time_array
         columns = self.generator_names
@@ -471,7 +486,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def create_generation_delta_report(self):
 
-        title = ResultTypes.TsGenerationDeltaReport.value[0]
+        title = ResultTypes.TsGenerationDeltaReport.value
 
         labels = self.time_array
         columns = self.generator_names
@@ -491,7 +506,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def create_base_report(self, loading_threshold, reverse):
 
-        title = f'{ResultTypes.TsBaseFlowReport.value[0]}. ' \
+        title = f'{ResultTypes.TsBaseFlowReport.value}. ' \
                 f'Loading threshold: {str(loading_threshold)}. ' \
                 f'Reverse: {str(reverse)}'
 
@@ -538,7 +553,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def create_contingency_full_report(self, loading_threshold=0.0, reverse=True):
 
-        title = f'{ResultTypes.TsContingencyFlowReport.value[0]}. ' \
+        title = f'{ResultTypes.TsContingencyFlowReport.value}. ' \
                 f'Loading threshold: {str(loading_threshold)}. ' \
                 f'Reverse: {str(reverse)}'
 
@@ -597,7 +612,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def create_contingency_branch_report(self, loading_threshold=0.0, reverse=True):
 
-        title = f'{ResultTypes.TsContingencyFlowBranchReport.value[0]}. ' \
+        title = f'{ResultTypes.TsContingencyFlowBranchReport.value}. ' \
                 f'Loading threshold: {str(self.loading_threshold_to_report)}. ' \
                 f'Reverse: {str(reverse)}'
 
@@ -652,7 +667,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def create_contingency_generation_report(self, loading_threshold=0.0, reverse=True):
 
-        title = f'{ResultTypes.TsContingencyFlowGenerationReport.value[0]}. ' \
+        title = f'{ResultTypes.TsContingencyFlowGenerationReport.value}. ' \
                 f'Loading threshold: {str(loading_threshold)}. ' \
                 f'Reverse: {str(reverse)}'
 
@@ -708,7 +723,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def create_contingency_hvdc_report(self, loading_threshold=0.0, reverse=True):
 
-        title = f'{ResultTypes.TsContingencyFlowHvdcReport.value[0]}. ' \
+        title = f'{ResultTypes.TsContingencyFlowHvdcReport.value}. ' \
                 f'Loading threshold: {str(loading_threshold)}. ' \
                 f'Reverse: {str(reverse)}'
 
@@ -753,7 +768,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
         self.reports[title] = ResultsTable(
             data=data_all,
-            index= np.arange(data_all.shape[0]),
+            index=np.arange(data_all.shape[0]),
             columns=columns_all,
             title=title,
             ylabel='(p.u.)',
@@ -763,7 +778,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def create_branch_monitoring_report(self):
 
-        title = ResultTypes.TsBranchMonitoring.value[0]
+        title = ResultTypes.TsBranchMonitoring.value
 
         if len(self.results_dict.values()) == 0:
             return
@@ -779,7 +794,8 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
                 mdl = self.results_dict[t].get_monitoring_logic_report()
 
                 # complete the report data with Time info
-                time_data = np.array([[t, self.time_array[idx].strftime("%d/%m/%Y %H:%M:%S")]] * mdl.get_data()[2].shape[0])
+                time_data = np.array(
+                    [[t, self.time_array[idx].strftime("%d/%m/%Y %H:%M:%S")]] * mdl.get_data()[2].shape[0])
                 data = np.concatenate((np.array([mdl.get_data()[0]]).T, time_data, mdl.get_data()[2]), axis=1)
 
                 # add to main data set
@@ -797,7 +813,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def create_contingency_branches_report(self, loading_threshold=100.0, reverse=True):
 
-        title = f'{ResultTypes.TsContingencyBranches.value[0]}. ' \
+        title = f'{ResultTypes.TsContingencyBranches.value}. ' \
                 f'Loading threshold: {str(loading_threshold)}. ' \
                 f'Reverse: {str(reverse)}'
 
@@ -839,7 +855,7 @@ class OptimalNetTransferCapacityTimeSeriesResults(ResultsTemplate):
 
     def create_critical_branches_report(self, loading_threshold=100.0, reverse=True):
 
-        title = f'{ResultTypes.TsCriticalBranches.value[0]}. ' \
+        title = f'{ResultTypes.TsCriticalBranches.value}. ' \
                 f'Loading threshold: {str(loading_threshold)}. ' \
                 f'Reverse: {str(reverse)}'
 
