@@ -133,8 +133,7 @@ class OptimalPowerFlowTimeSeriesDriver(TimeSeriesDriverTemplate):
                                          all_generators_fixed=False,
                                          lodf_threshold=self.options.lodf_tolerance,
                                          maximize_inter_area_flow=self.options.maximize_flows,
-                                         areas_from=self.options.areas_from,
-                                         areas_to=self.options.areas_to,
+                                         inter_aggregation_info=self.options.inter_aggregation_info,
                                          logger=self.logger,
                                          progress_text=self.report_text,
                                          progress_func=self.report_progress,
@@ -297,8 +296,7 @@ class OptimalPowerFlowTimeSeriesDriver(TimeSeriesDriverTemplate):
                                          all_generators_fixed=False,
                                          lodf_threshold=self.options.lodf_tolerance,
                                          maximize_inter_area_flow=self.options.maximize_flows,
-                                         areas_from=self.options.areas_from,
-                                         areas_to=self.options.areas_to,
+                                         inter_aggregation_info=self.options.inter_aggregation_info,
                                          energy_0=energy_0,
                                          fluid_level_0=fluid_level_0,
                                          logger=self.logger,
