@@ -262,6 +262,7 @@ def helm_coefficients_josep(Ybus, Yseries, V0, S0, Ysh0, pq, pv, sl, pqpv, toler
     """
     Holomorphic Embedding LoadFlow Method as formulated by Josep Fanals Batllori in 2020
     THis function just returns the coefficients for further usage in other routines
+    :param Ybus: Admittance matrix
     :param Yseries: Admittance matrix of the series elements
     :param V0: vector of specified voltages
     :param S0: vector of specified power
@@ -394,9 +395,11 @@ def helm_coefficients_josep(Ybus, Yseries, V0, S0, Ysh0, pq, pv, sl, pqpv, toler
         valor[pq_] = (vec_P[pq_] - vec_Q[pq_] * 1j) * X[c - 1, pq_] - U[c - 1, pq_] * Ysh[pq_]
         valor[pv_] = -1j * conv2(X, Q, c, pv_) - U[c - 1, pv_] * Ysh[pv_] + X[c - 1, pv_] * vec_P[pv_]
 
-        RHS = np.r_[valor.real,
-        valor.imag,
-        -conv3(U, U, c, pv_).real]
+        RHS = np.r_[
+            valor.real,
+            valor.imag,
+            -conv3(U, U, c, pv_).real
+        ]
 
         # LHS = spsolve(MAT, RHS)
         LHS = mat_factorized(RHS)
@@ -428,10 +431,30 @@ def helm_coefficients_josep(Ybus, Yseries, V0, S0, Ysh0, pq, pv, sl, pqpv, toler
 
 
 class HelmPreparation:
-
+    """
+    HelmPreparation
+    """
     def __init__(self, sys_mat_factorization, Uini, Xini, Yslack, Vslack,
                  vec_P, vec_Q, Ysh, vec_W, pq, pv, pqpv, sl,
                  npqpv, nbus):
+        """
+
+        :param sys_mat_factorization:
+        :param Uini:
+        :param Xini:
+        :param Yslack:
+        :param Vslack:
+        :param vec_P:
+        :param vec_Q:
+        :param Ysh:
+        :param vec_W:
+        :param pq:
+        :param pv:
+        :param pqpv:
+        :param sl:
+        :param npqpv:
+        :param nbus:
+        """
         self.sys_mat_factorization = sys_mat_factorization
         self.Uini = Uini
         self.Xini = Xini
@@ -644,7 +667,7 @@ def helm_coefficients_dY(dY, sys_mat_factorization, Uini, Xini, Yslack, Ysh, Ybu
     return U, V, iter_, norm_f
 
 
-def helm_josep(Ybus, Yseries, V0, S0, Ysh0, pq, pv, sl, pqpv, tolerance=1e-6, max_coefficients=30, use_pade=True,
+def helm_josep(Ybus, Yseries, V0, S0, Ysh0, pq, pv, vd, no_slack, tolerance=1e-6, max_coefficients=30, use_pade=True,
                verbose=False, logger: Logger = None) -> NumericPowerFlowResults:
     """
     Holomorphic Embedding LoadFlow Method as formulated by Josep Fanals Batllori in 2020
@@ -655,8 +678,8 @@ def helm_josep(Ybus, Yseries, V0, S0, Ysh0, pq, pv, sl, pqpv, tolerance=1e-6, ma
     :param Ysh0: vector of shunt admittances (including the shunt "legs" of the pi Branches)
     :param pq: list of pq nodes
     :param pv: list of pv nodes
-    :param sl: list of slack nodes
-    :param pqpv: sorted list of pq and pv nodes
+    :param vd: list of slack nodes
+    :param no_slack: sorted list of pq and pv nodes
     :param tolerance: target error (or tolerance)
     :param max_coefficients: maximum number of coefficients
     :param use_pade: Use the Padè approximation? otherwise, a simple summation is done
@@ -671,7 +694,7 @@ def helm_josep(Ybus, Yseries, V0, S0, Ysh0, pq, pv, sl, pqpv, tolerance=1e-6, ma
     if n < 2:
         # return NumericPowerFlowResults(V0, True, 0.0, S0, None, None, None, None, None, None, 0, 0.0)
         return NumericPowerFlowResults(V=V0, converged=True, norm_f=0.0,
-                                       Scalc=S0, ma=None, theta=None, Beq=None,
+                                       Scalc=S0, m=None, tau=None, Beq=None,
                                        Ybus=None, Yf=None, Yt=None,
                                        iterations=0, elapsed=0.0)
 
@@ -683,8 +706,8 @@ def helm_josep(Ybus, Yseries, V0, S0, Ysh0, pq, pv, sl, pqpv, tolerance=1e-6, ma
                                                            Ysh0=Ysh0,
                                                            pq=pq,
                                                            pv=pv,
-                                                           sl=sl,
-                                                           pqpv=pqpv,
+                                                           sl=vd,
+                                                           pqpv=no_slack,
                                                            tolerance=tolerance,
                                                            max_coeff=max_coefficients,
                                                            verbose=verbose,
@@ -698,14 +721,14 @@ def helm_josep(Ybus, Yseries, V0, S0, Ysh0, pq, pv, sl, pqpv, tolerance=1e-6, ma
     if use_pade:
         V = V0.copy()
         try:
-            V[pqpv] = pade4all(max_coefficients - 1, U, 1)
+            V[no_slack] = pade4all(max_coefficients - 1, U, 1)
         except:
             warn('Padè failed :(, using coefficients summation')
-            V[pqpv] = U.sum(axis=0)
+            V[no_slack] = U.sum(axis=0)
 
     # compute power mismatch
     Scalc = cf.compute_power(Ybus, V)
-    norm_f = cf.compute_fx_error(cf.compute_fx(Scalc, S0, pqpv, pq))
+    norm_f = cf.compute_fx_error(cf.compute_fx(Scalc, S0, no_slack, pq))
 
     # check convergence
     converged = norm_f < tolerance
@@ -714,6 +737,6 @@ def helm_josep(Ybus, Yseries, V0, S0, Ysh0, pq, pv, sl, pqpv, tolerance=1e-6, ma
 
     # return NumericPowerFlowResults(V, converged, norm_f, Scalc, None, None, None, None, None, None, iter_, elapsed)
     return NumericPowerFlowResults(V=V, converged=converged, norm_f=norm_f,
-                                   Scalc=Scalc, ma=None, theta=None, Beq=None,
+                                   Scalc=Scalc, m=None, tau=None, Beq=None,
                                    Ybus=None, Yf=None, Yt=None,
                                    iterations=iter_, elapsed=elapsed)
